@@ -35,7 +35,7 @@ module DeclarativePolicy
     def policy_class(domain_class_name)
       return unless domain_class_name
 
-      @class_for.call((@name_transformation.call(domain_class_name)))
+      @class_for.call(@name_transformation.call(domain_class_name))
     rescue NameError
       nil
     end
