@@ -33,10 +33,10 @@ module DeclarativePolicy
       @context_class.prevent_all_when(@rule)
     end
 
-    def method_missing(msg, *args, &block)
+    def method_missing(msg, ...)
       return super unless @context_class.respond_to?(msg)
 
-      @context_class.__send__(msg, *args, &block) # rubocop: disable GitlabSecurity/PublicSend
+      @context_class.__send__(msg, ...) # rubocop: disable GitlabSecurity/PublicSend
     end
 
     def respond_to_missing?(msg)
