@@ -2,7 +2,7 @@
 
 module DeclarativePolicy
   module PreferredScope
-    PREFERRED_SCOPE_KEY = :"DeclarativePolicy.preferred_scope"
+    PREFERRED_SCOPE_KEY = :'DeclarativePolicy.preferred_scope'
 
     def with_preferred_scope(scope)
       old_scope = Thread.current[PREFERRED_SCOPE_KEY]
